pub struct ManufacturerInfo {
pub part_id: String,
pub name: String,
}Expand description
Information about the manufacturer
Fields
part_id: Stringname: StringTrait Implementations
Sourceimpl Clone for ManufacturerInfo
impl Clone for ManufacturerInfo
Sourcefn clone(&self) -> ManufacturerInfo
fn clone(&self) -> ManufacturerInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ManufacturerInfo
impl Debug for ManufacturerInfo
Sourceimpl<'de> Deserialize<'de> for ManufacturerInfo
impl<'de> Deserialize<'de> for ManufacturerInfo
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ManufacturerInfo
impl JsonSchema for ManufacturerInfo
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ManufacturerInfo
impl PartialEq for ManufacturerInfo
Sourceimpl Serialize for ManufacturerInfo
impl Serialize for ManufacturerInfo
impl Eq for ManufacturerInfo
impl StructuralPartialEq for ManufacturerInfo