pub struct Contractor {
pub identifier: Option<ContractorIdentifier>,
pub contact: Option<ContactInfo>,
}Expand description
Who did the work (cXML <Contractor>)
Fields
identifier: Option<ContractorIdentifier>contact: Option<ContactInfo>Trait Implementations
Sourceimpl Clone for Contractor
impl Clone for Contractor
Sourcefn clone(&self) -> Contractor
fn clone(&self) -> Contractor
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for Contractor
impl Debug for Contractor
Sourceimpl<'de> Deserialize<'de> for Contractor
impl<'de> Deserialize<'de> for Contractor
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for Contractor
impl JsonSchema for Contractor
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for Contractor
impl RefUnwindSafe for Contractor
impl Send for Contractor
impl Sync for Contractor
impl Unpin for Contractor
impl UnwindSafe for Contractor