pub struct FeeDetail {
pub amount: Money,
pub description: Option<String>,
pub extrinsic: Option<HashMap<String, String>>,
}Expand description
Optional “fee” style charge
Fields
amount: Moneydescription: Option<String>extrinsic: Option<HashMap<String, String>>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for FeeDetail
impl<'de> Deserialize<'de> for FeeDetail
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for FeeDetail
impl JsonSchema for FeeDetail
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for FeeDetail
impl RefUnwindSafe for FeeDetail
impl Send for FeeDetail
impl Sync for FeeDetail
impl Unpin for FeeDetail
impl UnwindSafe for FeeDetail