pub struct SpendDetail {
pub travel_detail: Option<TravelDetail>,
pub fee_detail: Option<FeeDetail>,
pub labor_detail: Option<LaborDetail>,
pub extrinsic: Option<HashMap<String, String>>,
}Expand description
Mirrors cXML <SpendDetail> → may contain Travel, Fee, and/or Labor
Fields
travel_detail: Option<TravelDetail>fee_detail: Option<FeeDetail>labor_detail: Option<LaborDetail>extrinsic: Option<HashMap<String, String>>Trait Implementations
Sourceimpl Clone for SpendDetail
impl Clone for SpendDetail
Sourcefn clone(&self) -> SpendDetail
fn clone(&self) -> SpendDetail
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SpendDetail
impl Debug for SpendDetail
Sourceimpl<'de> Deserialize<'de> for SpendDetail
impl<'de> Deserialize<'de> for SpendDetail
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SpendDetail
impl JsonSchema for SpendDetail
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SpendDetail
impl RefUnwindSafe for SpendDetail
impl Send for SpendDetail
impl Sync for SpendDetail
impl Unpin for SpendDetail
impl UnwindSafe for SpendDetail