pub struct TermReference {
pub term_name: String,
pub term: String,
}Expand description
Identifies the meaning of a UnitRate (cXML <TermReference>)
Fields
term_name: Stringterm: StringTrait Implementations
Sourceimpl Clone for TermReference
impl Clone for TermReference
Sourcefn clone(&self) -> TermReference
fn clone(&self) -> TermReference
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TermReference
impl Debug for TermReference
Sourceimpl<'de> Deserialize<'de> for TermReference
impl<'de> Deserialize<'de> for TermReference
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TermReference
impl JsonSchema for TermReference
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for TermReference
impl RefUnwindSafe for TermReference
impl Send for TermReference
impl Sync for TermReference
impl Unpin for TermReference
impl UnwindSafe for TermReference