pub struct TransportEvent {
pub code: TransportEventCode,
pub timestamp: DateTime<Utc>,
pub source: Option<String>,
pub note: Option<String>,
}Expand description
Execution/visibility event (optional stream)
Fields
code: TransportEventCodetimestamp: DateTime<Utc>source: Option<String>Who reported it (carrier/TSP, telematics, port, visibility provider…)
note: Option<String>Trait Implementations
Sourceimpl Clone for TransportEvent
impl Clone for TransportEvent
Sourcefn clone(&self) -> TransportEvent
fn clone(&self) -> TransportEvent
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TransportEvent
impl Debug for TransportEvent
Sourceimpl<'de> Deserialize<'de> for TransportEvent
impl<'de> Deserialize<'de> for TransportEvent
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TransportEvent
impl JsonSchema for TransportEvent
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for TransportEvent
impl PartialEq for TransportEvent
Sourceimpl Serialize for TransportEvent
impl Serialize for TransportEvent
impl Eq for TransportEvent
impl StructuralPartialEq for TransportEvent