Structs
- Address
- Address definition
- Cargo
Summary - What you’re moving (high-level)
- Classification
- Classification (UNSPSC, ECLASS, …)
- Contact
Info - Minimal contact info for supervisors/contractors (maps to cXML
<Contact>) - Contractor
- Who did the work (cXML
<Contractor>) - Contractor
Identifier - Contractor identifier (cXML
<ContractorIdentifier domain=...>) - Equipment
- Equipment / container / trailer requirements
- FeeDetail
- Optional “fee” style charge
- Item
- Datatype for a single item - bundles item-id and item-detail
- Item
Detail - Details of a single position in the purchase order
- ItemID
- Supplier and buyer part/item ID
- ItemOut
- A single item position in the purchase order
- Labor
Detail - Labor service details (subset of cXML
<LaborDetail>) - LegStop
- An intermediate stop (for multi-pick/drop). Each stop can model both arrival & departure.
- Manufacturer
Info - Information about the manufacturer
- Order
Request - The full request datatype for a purchase order
- Order
Request Header - Header of an order-request
- Period
- Time period for a service (cXML
<Period>) - Price
Basis Quantity - Quantity + UOM that the price is based on (cXML
<PriceBasisQuantity>) - Spend
Detail - Mirrors cXML
<SpendDetail>→ may contain Travel, Fee, and/or Labor - Step
Timing - Requested vs planned vs estimated vs actual for one step (pickup or delivery)
- Term
Reference - Identifies the meaning of a
UnitRate(cXML<TermReference>) - Time
Window - A time window (site availability / appointment window)
- Transport
Event - Execution/visibility event (optional stream)
- Transportation
Request - A transport service request/tender/booking (A→B or multi-stop)
- Travel
Detail - Optional “travel” style cost bucket (kept simple; extend as needed)
- Unit
Rate - Service pricing per time/measure unit (cXML
<UnitRate>)
Enums
- Accessorial
- Accessorial services (used to add cost / constraints on the delivery)
- Classification
Domain - Contractor
Identifier Domain - Order
Type - Defines if the order was “new”, an “update” or should be “delete“d
- Transport
Event Code - A compact event vocabulary
- Transport
Mode - Road/Air/Ocean/Rail or mixed
- Transport
Status - Where you are in the request→execution flow
- Unit
OfMeasure - ISO Units-of-Measure-Codes or a freely defined measure